@@ -2,7 +2,7 @@ from typing import Optional
 
 from pydantic import BaseModel
 
-MODEL_TYPE = 'contact_info'
+MODEL_TYPE = "contact_info"
 
 
 class CreateAPIContactInfoFields(BaseModel):
