@@ -3,7 +3,7 @@ from typing import Optional
 
 from pydantic import BaseModel
 
-MODEL_TYPE = 'guides_schools'
+MODEL_TYPE = "guides_school"
 
 
 class APIGuidesSchoolsFields(BaseModel):
