@@ -4,7 +4,7 @@ from pydantic import BaseModel
 
 from . import response as response_models
 
-MODEL_TYPE = 'hub'
+MODEL_TYPE = "hub"
 
 
 class APIHubFields(BaseModel):
@@ -31,5 +31,3 @@ class APIHubResponse(response_models.APIResponse):
 
 class ListAPIHubResponse(response_models.ListAPIResponse):
     data: list[Union[APIHubData, dict]]
-
-
