@@ -2,7 +2,7 @@ from typing import Optional
 
 from pydantic import BaseModel
 
-MODEL_TYPE = 'languages'
+MODEL_TYPE = "language"
 
 
 class CreateAPILanguagesFields(BaseModel):
