@@ -4,7 +4,7 @@ from pydantic import BaseModel
 
 from . import response as response_models
 
-MODEL_TYPE = 'partner'
+MODEL_TYPE = "partner"
 
 
 class APIPartnerFields(BaseModel):
@@ -35,4 +35,4 @@ class APIPartnerResponse(response_models.APIResponse):
 
 
 class ListAPIPartnerResponse(response_models.ListAPIResponse):
-    data: list[Union[APIPartnerData, dict]]
\ No newline at end of file
+    data: list[Union[APIPartnerData, dict]]
