@@ -4,7 +4,7 @@ from pydantic import BaseModel
 
 from . import response as response_models
 
-MODEL_TYPE = 'pod'
+MODEL_TYPE = "pod"
 
 
 class APIPodFields(BaseModel):
