@@ -22,13 +22,9 @@ class APILinksAndData(APILinks):
     data: Optional[Union[str, APIDataWithFields, APIDataBase, list[Union[str, APIDataWithFields, APIDataBase]]]]
 
 
-class APIRelationships(BaseModel):
-    __root__: dict[str, Union[APILinksAndData, APILinks]]
-
-
 class APIData(APIDataWithFields):
     fields: dict
-    relationships: APIRelationships
+    relationships: dict[str, Union[APILinksAndData, APILinks]]
     links: dict[str, Optional[str]]
 
 
