@@ -4,8 +4,9 @@ from typing import Optional, Union
 from pydantic import BaseModel, HttpUrl
 
 from . import response as response_models
+from .utils import copy_field
 
-MODEL_TYPE = 'school'
+MODEL_TYPE = "school"
 
 
 class APISchoolFields(BaseModel):
@@ -15,6 +16,8 @@ class APISchoolFields(BaseModel):
     logo_url: Optional[HttpUrl] = None
     domain_name: Optional[str] = None
     address: Optional[str] = None
+    hub_name: Optional[str] = None
+    pod_name: Optional[str] = None
     latitude: Optional[float] = None
     longitude: Optional[float] = None
 
@@ -38,6 +41,17 @@ class APISchoolFields(BaseModel):
     nonprofit_status: Optional[str] = None
     left_network_reason: Optional[str] = None
     left_network_date: Optional[date] = None
+    organizational_unit: Optional[str] = None
+
+
+class APISchoolMetaFields(BaseModel):
+    __annotations__ = getattr(BaseModel, "__annotations__", {}).copy()
+    copy_field(APISchoolFields, "name", __annotations__)
+    copy_field(APISchoolFields, "hub_name", __annotations__)
+    copy_field(APISchoolFields, "pod_name", __annotations__)
+    copy_field(APISchoolFields, "domain_name", __annotations__)
+    copy_field(APISchoolFields, "status", __annotations__)
+    copy_field(APISchoolFields, "ssj_stage", __annotations__)
 
 
 class APISchoolRelationships(BaseModel):
@@ -62,4 +76,4 @@ class APISchoolResponse(response_models.APIResponse):
 
 
 class ListAPISchoolResponse(response_models.ListAPIResponse):
-    data: list[Union[APISchoolData, dict]]
\ No newline at end of file
+    data: list[Union[APISchoolData, dict]]
